-- name: \\#E10A49\\[CS] Megumin
-- description: Megumin v1.0\nModeled by Oradimi.\n\nYou need the Character Select mod.\nType /char-select to select.

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation
]]

local MOD_VERSION = _G.charSelect.version_get()
local MAJOR, MINOR, PATCH = string.match(MOD_VERSION, "(%d+)%.(%d+)%.?(%d*)")
MAJOR, MINOR, PATCH = tonumber(MAJOR), tonumber(MINOR), tonumber(PATCH) or 0
local V1_8_OR_ABOVE = MAJOR > 1 or (MAJOR == 1 and MINOR >= 8)

local TEXT_MOD_NAME = "Megumin"

-- MEGUMIN --

local E_MODEL_MEGUMIN = smlua_model_util_get_id("megumin_geo")
local E_MODEL_MEGUMIN_R = smlua_model_util_get_id("megumin_geo_r")
local CAPTABLE_MEGUMIN = {
    normal = smlua_model_util_get_id("megumin_cap_geo"),
    wing = smlua_model_util_get_id("megumin_wing_cap_geo"),
    metal = smlua_model_util_get_id("megumin_metal_cap_geo"),
    metalWing = smlua_model_util_get_id("megumin_metal_wing_cap_geo"),
}
local PALETTE_MEGUMIN = nil
if V1_8_OR_ABOVE then
	PALETTE_MEGUMIN = {
		[PANTS]  = "5f4f5d",
		[SHIRT]  = "ff0b53",
		[GLOVES] = "ffffff",
		[SHOES]  = "e36e4c",
		[HAIR]   = "6d5056",
		[SKIN]   = "6d5056",
		[CAP]    = "563d43",
	}
end
local VOICETABLE_MEGUMIN = {
    [CHAR_SOUND_ATTACKED] = {'megumin_ugh1.mp3', 'megumin_cry1.mp3'},
	[CHAR_SOUND_COUGHING1] = 'megumin_cough.mp3',
    [CHAR_SOUND_COUGHING2] = 'megumin_cough.mp3',
	[CHAR_SOUND_COUGHING3] = 'megumin_cough.mp3',
    [CHAR_SOUND_DOH] = 'megumin_ah2.mp3', -- Bonk into walls
	--[CHAR_SOUND_DROWNING] = 'silent.mp3',
    [CHAR_SOUND_DYING] = {'megumin_fue2.mp3', 'megumin_ha1.mp3', 'megumin_cry2.mp3'},
    [CHAR_SOUND_EEUH] = {'megumin_haa1.mp3',}, -- Slow Get up from ledge
    --[CHAR_SOUND_GAME_OVER] = {'silent.mp3'},
    [CHAR_SOUND_GROUND_POUND_WAH] = {'megumin_sigh1.mp3', 'megumin_fue1.mp3',},
    [CHAR_SOUND_HAHA] = {'megumin_huhuhun.mp3'}, -- Landing after backflip
    --[CHAR_SOUND_HAHA_2] = 'silent.mp3', -- Landing on Water after a fall
    --[CHAR_SOUND_HELLO] = 'silent.mp3',
    [CHAR_SOUND_HERE_WE_GO] = {'megumin_nicebakurestu.mp3'}, -- Star Get + Obtaining Power-up
    [CHAR_SOUND_HOOHOO] = {'megumin_oh2.mp3'}, -- 2nd Jump + Dive Attack
    [CHAR_SOUND_HRMM] = 'megumin_huhuhun.mp3', -- Object Pick-up
    [CHAR_SOUND_IMA_TIRED] = 'megumin_mou1.mp3',
    [CHAR_SOUND_LETS_A_GO] = {'megumin_chunmaru1.mp3', 'megumin_chunmaru2.mp3'}, -- Level Select
    [CHAR_SOUND_MAMA_MIA] = 'megumin_mou1.mp3', -- Getting up after thrown out of level
	[CHAR_SOUND_OKEY_DOKEY] = 'menumin_wagana.mp3',
    [CHAR_SOUND_ON_FIRE] = {'megumin_ahh1.mp3',}, -- Touch Fire
    [CHAR_SOUND_OOOF] = {'megumin_gasp1.mp3', 'megumin_gasp2.mp3'},
    [CHAR_SOUND_OOOF2] = {'megumin_fue2.mp3', 'megumin_gasp2.mp3'}, -- Landing After a Bonk + Thrown out of level
    [CHAR_SOUND_PANTING] = {'megumin_ha1.mp3',}, -- Low Health
    --[CHAR_SOUND_PANTING_COLD] = 'silent.mp3',
    --[CHAR_SOUND_PRESS_START_TO_PLAY] = {'silent.mp3', 'silent.mp3'},
    [CHAR_SOUND_PUNCH_HOO] = {'megumin_haa2.mp3',}, -- Kick
    [CHAR_SOUND_PUNCH_WAH] = 'megumin_ha4.mp3', -- 2nd Punch
    [CHAR_SOUND_PUNCH_YAH] = 'megumin_oh2.mp3', -- 1st Punch
    --[CHAR_SOUND_SNORING1] = 'silent.mp3',
    --[CHAR_SOUND_SNORING2] = 'silent.mp3',
    --[CHAR_SOUND_SNORING3] = {'silent.mp3'},
    [CHAR_SOUND_SO_LONGA_BOWSER] = {'megumin_explosion1.mp3'}, -- Bowser Throw
    [CHAR_SOUND_TWIRL_BOUNCE] = {'megumin_ha1.mp3'}, -- Boing
    [CHAR_SOUND_UH] = 'megumin_uh1.mp3', -- Drop off of ledge
    [CHAR_SOUND_UH2] = {'megumin_uh1.mp3',}, -- ???
    [CHAR_SOUND_UH2_2] = 'megumin_huhuhun.mp3', -- Landing after Long Jump
    [CHAR_SOUND_WAAAOOOW] = 'megumin_ahh1.mp3', -- Falling
    [CHAR_SOUND_WAH2] = 'megumin_explosion3.mp3', -- Throw Object
    [CHAR_SOUND_WHOA] = {'megumin_he1.mp3', 'megumin_ah2.mp3'}, -- Ledge Grab
    [CHAR_SOUND_YAHOO] = {'megumin_haa2.mp3',}, -- Long Jump
    [CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'megumin_haa2.mp3'}, -- 3rd Jump
    [CHAR_SOUND_YAH_WAH_HOO] = {'megumin_ha4.mp3'}, -- 1st Jump
    --[CHAR_SOUND_YAWNING] = 'silent.mp3',
}

local TABLE_OF_VOICES = {
    VOICETABLE_MEGUMIN
}

-- Function aliases
local cs_char_add = _G.charSelect.character_add
local cs_char_add_voice = _G.charSelect.character_add_voice
local cs_char_get_voice = _G.charSelect.character_get_voice
local cs_voice_sound = _G.charSelect.voice.sound
local cs_voice_snore = _G.charSelect.voice.snore
local cs_char_add_caps = _G.charSelect.character_add_caps
local cs_char_add_palette_preset = nil
if V1_8_OR_ABOVE then
	cs_char_add_palette_preset = _G.charSelect.character_add_palette_preset
end

if _G.charSelectExists then
	cs_char_add(
		"Megumin",
		{
			"\"Explosion!\"",
			"The famous explosion",
			"magic lover from KonoSuba."
		},
		"Natsume Akatsuki / Oradimi",
		{r = 225, g = 10, b = 73},
		E_MODEL_MEGUMIN, CT_MARIO, gTextures.mario_head
	)
	cs_char_add(
		"Megumin (Recolor)",
		{
			"\"Explosion!\"",
			"The famous explosion",
			"magic lover from KonoSuba.",
			"Can be recolored."
		},
		"Natsume Akatsuki / Oradimi",
		{r = 225, g = 10, b = 73},
		E_MODEL_MEGUMIN_R, CT_MARIO, gTextures.mario_head
	)

-- All Caps and Voices
	cs_char_add_caps(E_MODEL_MEGUMIN, CAPTABLE_MEGUMIN)
	cs_char_add_voice(E_MODEL_MEGUMIN, VOICETABLE_MEGUMIN)
	
	cs_char_add_caps(E_MODEL_MEGUMIN_R, CAPTABLE_MEGUMIN)
    cs_char_add_voice(E_MODEL_MEGUMIN_R, VOICETABLE_MEGUMIN)
	if V1_8_OR_ABOVE then
		cs_char_add_palette_preset(E_MODEL_MEGUMIN_R, PALETTE_MEGUMIN)
	end

    hook_event(HOOK_CHARACTER_SOUND, function (m, sound)
        for i = 1, #TABLE_OF_VOICES do
            if cs_char_get_voice(m) == TABLE_OF_VOICES[i] then return cs_voice_sound(m, sound) end
        end
    end)
    hook_event(HOOK_MARIO_UPDATE, function (m)
        for i = 1, #TABLE_OF_VOICES do
            if cs_char_get_voice(m) == TABLE_OF_VOICES[i] then return cs_voice_snore(m) end
        end
    end)
else
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
end